@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Patch.py 12627 2020-11-26 10:59:32Z Lavender $
+# $Id: Patch.py 12638 2020-12-17 07:19:51Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,13 +12,15 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-11-26 19:59:32 +0900 (週四, 26 十一月 2020) $
-# $Revision: 12627 $
+# $Date: 2020-12-17 16:19:51 +0900 (週四, 17 十二月 2020) $
+# $Revision: 12638 $
 #
 # Contributors:
 #  Bear
 #  Yachu
 
+import importlib
+
 from Iuppiter.DjangoUtil import (
     extendInstalledApps, extendMiddlewareClasses, DJANGO_VERSION, patterns)
 from Iuppiter.Util import colored
@@ -201,6 +203,19 @@ def attachDebugURLs(settings, urlpatterns):
             urlpatterns += patterns('',
                 url(r'^__debug__/', include(debug_toolbar.urls)),
             )
+            
+def checkImportPackage(packageName):
+    """
+    Check the package you want to import and 
+    raise an ImportError if the package is not available.
+    
+    @param packageName Package name.
+    @param settingsDict Settings dict.
+    """
+    try:
+        return importlib.import_module(packageName)
+    except ImportError:
+        return False
 
 def attachURLs(settings, urlpatterns):
     """
@@ -217,54 +232,25 @@ def attachURLs(settings, urlpatterns):
     from des import urls as des_urls
 
     from Iuno.cloud.logging.views import sendLog
-
-    urlpatterns += patterns('',
-        url(r'^django-des/', include(des_urls)),
-        url(r'^log/', csrf_exempt(partial(sendLog,
-            title=settings.APP_NAME if hasattr(settings, 'APP_NAME') else '')),
-            name='sendLog'),
-    )
     
-    addMetricsUrl = False
-    if hasattr(settings ,'IUNO_CLOUD_ENABLE'):
-        if settings.IUNO_CLOUD_ENABLE:
-            if hasattr(settings ,'IUNO_CLOUD_SERVICES'):
-                services = settings.IUNO_CLOUD_SERVICES
-                if 'metrics' in services:
-                    addMetricsUrl = True
-            else:
-                addMetricsUrl = True
-                
-    if addMetricsUrl:
-        from Iuno.cloud.metrics.views import sendStatsd, getStatsdImage
-        urlpatterns += patterns('',
-            url(r'^metrics/send/', sendStatsd, name='sendStatsd'),
-            url(r'^metrics/image/', getStatsdImage, name='getStatsdImage'),
-        )
-        
-    addCloudSMSAPIUrl = False
-    if hasattr(settings ,'IUNO_CLOUD_ENABLE'):
-        if settings.IUNO_CLOUD_ENABLE:
-            if hasattr(settings ,'IUNO_CLOUD_SERVICES'):
-                services = settings.IUNO_CLOUD_SERVICES
-                if 'sms' in services:
-                    addCloudSMSAPIUrl = True
-            else:
-                addCloudSMSAPIUrl = True
-                
-    if addCloudSMSAPIUrl:
-        from Iuno.cloud.sms.views import callAPISMS
-        urlpatterns += patterns('',
-            url(r'^sms/api/send/', callAPISMS, name='callAPISMS'),
-        )
-        
-    if hasattr(settings ,  'IUNO_CLOUD_SMS_CLIENT_ENABLE'):
-        from Iuno.cloud.sms.views import sendSMSCaptcha
-        urlpatterns += patterns('',
-            url(r'^sms/captcha/send/', sendSMSCaptcha, name='sendSMSCaptcha'),
-        )
-        
-        
+    #=========================================================================
+    # Iuno.cloud.
+    try:
+        module = checkImportPackage('Iuno.cloud')
+    except ImportError:
+        pass
+    else:
+        if module:
+            import Iuno.cloud
+            
+    if getattr(settings, 'IUNO_CLOUD_ENABLE', None) and module:
+        attachCloudKws = {}
+        if hasattr(settings, 'IUNO_CLOUD_SERVICES'):
+            attachCloudKws['services'] = settings.IUNO_CLOUD_SERVICES
+    
+        Iuno.cloud.attachURLs(settings, urlpatterns, **attachCloudKws)
+    
+    #==========================================================================
     addTestUrl = False
     if hasattr(settings ,'IUNO_TEST_ENABLE'):
         addTestUrl = settings.IUNO_TEST_ENABLE
