@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11631 2019-06-11 20:19:44Z Lavender $
+# $Id: __init__.py 12638 2020-12-17 07:19:51Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-06-12 04:19:44 +0800 (週三, 12 六月 2019) $
-# $Revision: 11631 $
+# $Date: 2020-12-17 16:19:51 +0900 (週四, 17 十二月 2020) $
+# $Revision: 12638 $
 
 # Avoid conflict with Iuno.cloud.logging moudle.
 from __future__ import absolute_import
@@ -322,3 +322,18 @@ def tryGet(methodName, backends, preferred=None, *args, **kws):
         if info:
             return HostInfo(backend, info)
     return None
+
+def attachURLs(settings, urlpatterns, services=(
+                    'queue', 'mail', 'logging', 
+                    'browser', 'storage', 'metrics')):
+                    
+    for service in services:
+        try:
+            serviceAttachURLs = classForName('Iuno.cloud.%s.attachURLs' % service)
+        except ImportError as ex:
+            logger.warn('%s can not be imported: %s' % (service, str(ex)))
+            continue
+        
+        serviceAttachURLs(settings, urlpatterns)
+                    
+    
