@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11859 2020-01-12 11:48:41Z Lavender $
+# $Id: __init__.py 12638 2020-12-17 07:19:51Z Lavender $
 #
 # Copyright (c) 2019 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-01-12 20:48:41 +0900 (週日, 12 一月 2020) $
-# $Revision: 11859 $
+# $Date: 2020-12-17 16:19:51 +0900 (週四, 17 十二月 2020) $
+# $Revision: 12638 $
 #
 # Contributors:
 #  Bear (original author)
@@ -22,7 +22,7 @@
 from Iuno.Util import update
 
 from Iuppiter.DjangoUtil import (
-    extendInstalledApps, extendMiddlewareClasses)
+    extendInstalledApps, extendMiddlewareClasses, patterns)
 
 def attachSettings(settingsLocals, backends, preferred, config):
     """
@@ -59,4 +59,24 @@ def attachSettings(settingsLocals, backends, preferred, config):
     }
     
     update(settingsLocals, DEFAULT_STATSD_SETTINGS)
+    
+def attachURLs(settings, urlpatterns):
+    from django.conf.urls import url
+    from Iuno.cloud.metrics.views import sendStatsd, getStatsdImage
+    
+    addMetricsUrl = False
+    if hasattr(settings ,'IUNO_CLOUD_ENABLE'):
+        if settings.IUNO_CLOUD_ENABLE:
+            if hasattr(settings ,'IUNO_CLOUD_SERVICES'):
+                services = settings.IUNO_CLOUD_SERVICES
+                if 'metrics' in services:
+                    addMetricsUrl = True
+            else:
+                addMetricsUrl = True
+                
+    if addMetricsUrl:
+        urlpatterns += patterns('',
+            url(r'^metrics/send/', sendStatsd, name='sendStatsd'),
+            url(r'^metrics/image/', getStatsdImage, name='getStatsdImage'),
+        )
 
